==> gnustep-dl2_0.9.1.orig.tar.gz: gnustep-dl2-0.9.1.orig/EOControl/EOControl.h <==
/* 
   EOControl.h

   Copyright (C) 2000-2002 Free Software Foundation, Inc.

   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
   Date: February 2000

   This file is part of the GNUstep Database Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef __EOControl_h__
#define __EOControl_h__


#include <EOControl/EOSortOrdering.h>
#include <EOControl/EOFetchSpecification.h>
#include <EOControl/EOGenericRecord.h>
#include <EOControl/EOClassDescription.h>
#include <EOControl/EOKeyValueCoding.h>
#include <EOControl/EOQualifier.h>
#include <EOControl/EONull.h>
#include <EOControl/EOKeyValueArchiver.h>
#include <EOControl/EOGlobalID.h>
#include <EOControl/EOKeyGlobalID.h>
#include <EOControl/EOObjectStore.h>
#include <EOControl/EOObjectStoreCoordinator.h>
#include <EOControl/EOFault.h>
#include <EOControl/EOEditingContext.h>
#include <EOControl/EODataSource.h>
#include <EOControl/EOArrayDataSource.h>
#include <EOControl/EODetailDataSource.h>
#include <EOControl/EOObserver.h>
#include <EOControl/EODebug.h>


#endif /* __EOControl_h__ */

==> gnustep-dl2_0.10.1.orig.tar.gz: gnustep-dl2-0.10.1/EOControl/EOControl.h <==
/* 
   EOControl.h

   Copyright (C) 2000-2002,2003,2005 Free Software Foundation, Inc.

   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
   Date: February 2000

   This file is part of the GNUstep Database Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef __EOControl_h__
#define __EOControl_h__


#include <EOControl/EOSortOrdering.h>
#include <EOControl/EOFetchSpecification.h>
#include <EOControl/EOGenericRecord.h>
#include <EOControl/EOClassDescription.h>
#include <EOControl/EOKeyValueCoding.h>
#include <EOControl/EOQualifier.h>
#include <EOControl/EONull.h>
#include <EOControl/EOKeyValueArchiver.h>
#include <EOControl/EOGlobalID.h>
#include <EOControl/EOKeyGlobalID.h>
#include <EOControl/EOObjectStore.h>
#include <EOControl/EOObjectStoreCoordinator.h>
#include <EOControl/EOFault.h>
#include <EOControl/EOEditingContext.h>
#include <EOControl/EOSharedEditingContext.h>
#include <EOControl/EODataSource.h>
#include <EOControl/EOArrayDataSource.h>
#include <EOControl/EODetailDataSource.h>
#include <EOControl/EOObserver.h>
#include <EOControl/EOMultiReaderLock.h>
#include <EOControl/EOEvent.h>
#include <EOControl/EOEventCenter.h>
#include <EOControl/EODebug.h>


#endif /* __EOControl_h__ */
